@@ -128,6 +128,7 @@ class WhereConditionPartialQuery(PartialQuery):
         self.query = query
 
     def construct_query(self) -> str:
+        """Constructs a where partial query."""
         return f" {self.keyword} {self.query} "
 
 
@@ -152,6 +153,7 @@ class NodePartialQuery(PartialQuery):
         return self._properties if self._properties is not None else ""
 
     def construct_query(self) -> str:
+        """Constructs a node partial query."""
         return f"({self.variable}{self.labels}{self.properties})"
 
 
@@ -180,6 +182,7 @@ class EdgePartialQuery(PartialQuery):
         return self._properties if self._properties is not None else ""
 
     def construct_query(self) -> str:
+        """Constructs an edge partial query."""
         relationship_query = f"{self.variable}{self.labels}{self.properties}"
 
         if not self.directed:
@@ -202,10 +205,14 @@ class UnwindPartialQuery(PartialQuery):
         self.variable = variable
 
     def construct_query(self) -> str:
+        """Constructs an unwind partial query."""
         return f" UNWIND {self.list_expression} AS {self.variable} "
 
 
 def dict_to_alias_statement(alias_dict: Dict[str, str]) -> str:
+    """Creates a string expression of alias statements from a dictionary of
+    expression, variable name dictionary.
+    """
     return ", ".join(
         f"{key} AS {value}" if value != "" and key != value else f"{key}" for (key, value) in alias_dict.items()
     )
@@ -222,6 +229,7 @@ class WithPartialQuery(PartialQuery):
         return self._results if self._results is not None else ""
 
     def construct_query(self) -> str:
+        """Creates a WITH statement Cypher partial query."""
         if len(self.results) == 0:
             return " WITH * "
         return f" WITH {dict_to_alias_statement(self.results)} "
@@ -234,6 +242,7 @@ class UnionPartialQuery(PartialQuery):
         self.include_duplicates = include_duplicates
 
     def construct_query(self) -> str:
+        """Creates a UNION statement Cypher partial query."""
         return f" UNION{f' ALL' if self.include_duplicates else ''} "
 
 
@@ -249,6 +258,7 @@ class DeletePartialQuery(PartialQuery):
         return self._variable_expressions if self._variable_expressions is not None else ""
 
     def construct_query(self) -> str:
+        """Creates a DELETE statement Cypher partial query."""
         return f" {'DETACH' if self.detach else ''} DELETE {', '.join(self.variable_expressions)} "
 
 
@@ -263,6 +273,7 @@ class RemovePartialQuery(PartialQuery):
         return self._items if self._items is not None else ""
 
     def construct_query(self) -> str:
+        """Creates a REMOVE statement Cypher partial query."""
         return f" REMOVE {', '.join(self.items)} "
 
 
@@ -277,6 +288,7 @@ class YieldPartialQuery(PartialQuery):
         return self._results if self._results is not None else ""
 
     def construct_query(self) -> str:
+        """Creates a YIELD statement Cypher partial query."""
         if len(self.results) == 0:
             return " YIELD * "
         return f" YIELD {dict_to_alias_statement(self.results)} "
@@ -293,6 +305,7 @@ class ReturnPartialQuery(PartialQuery):
         return self._results if self._results is not None else ""
 
     def construct_query(self) -> str:
+        """Creates a RETURN statement Cypher partial query."""
         if len(self.results) == 0:
             return " RETURN * "
         return f" RETURN {dict_to_alias_statement(self.results)} "
@@ -305,6 +318,7 @@ class OrderByPartialQuery(PartialQuery):
         self.properties = properties
 
     def construct_query(self) -> str:
+        """Creates a ORDER BY statement Cypher partial query."""
         return f" ORDER BY {self.properties} "
 
 
@@ -315,6 +329,7 @@ class LimitPartialQuery(PartialQuery):
         self.integer_expression = integer_expression
 
     def construct_query(self) -> str:
+        """Creates a LIMIT statement Cypher partial query."""
         return f" LIMIT {self.integer_expression} "
 
 
@@ -325,6 +340,7 @@ class SkipPartialQuery(PartialQuery):
         self.integer_expression = integer_expression
 
     def construct_query(self) -> str:
+        """Creates a SKIP statement Cypher partial query."""
         return f" SKIP {self.integer_expression} "
 
 
@@ -344,21 +360,25 @@ class DeclarativeBase(ABC):
         self._connection = connection if connection is not None else Memgraph()
 
     def match(self, optional: bool = False) -> "DeclarativeBase":
+        """Creates a MATCH statement Cypher partial query."""
         self._query.append(MatchPartialQuery(optional))
 
         return self
 
     def merge(self) -> "DeclarativeBase":
+        """Creates a MERGE statement Cypher partial query."""
         self._query.append(MergePartialQuery())
 
         return self
 
     def create(self) -> "DeclarativeBase":
+        """Creates a CREATE statement Cypher partial query."""
         self._query.append(CreatePartialQuery())
 
         return self
 
     def call(self, procedure: str, arguments: Optional[str] = None) -> "DeclarativeBase":
+        """Creates a CALL statement Cypher partial query."""
         self._query.append(CallPartialQuery(procedure, arguments))
 
         return self
@@ -370,6 +390,7 @@ class DeclarativeBase(ABC):
         node: Optional["Node"] = None,
         **kwargs,
     ) -> "DeclarativeBase":
+        """Creates a node Cypher partial query."""
         if not self._is_linking_valid_with_query(DeclarativeBaseTypes.NODE):
             raise InvalidMatchChainException()
 
@@ -392,6 +413,7 @@ class DeclarativeBase(ABC):
         relationship: Optional["Relationship"] = None,
         **kwargs,
     ) -> "DeclarativeBase":
+        """Creates a relationship Cypher partial query with a '->' sign."""
         if not self._is_linking_valid_with_query(DeclarativeBaseTypes.EDGE):
             raise InvalidMatchChainException()
 
@@ -414,6 +436,7 @@ class DeclarativeBase(ABC):
         relationship: Optional["Relationship"] = None,
         **kwargs,
     ) -> "Match":
+        """Creates a relationship Cypher partial query with a '<-' sign."""
         if not self._is_linking_valid_with_query(DeclarativeBaseTypes.EDGE):
             raise InvalidMatchChainException()
 
@@ -429,6 +452,7 @@ class DeclarativeBase(ABC):
         return self
 
     def where(self, property: str, operator: str, value: Any) -> "DeclarativeBase":
+        """Creates a WHERE statement Cypher partial query."""
         value_cypher = to_cypher_value(value)
         self._query.append(
             WhereConditionPartialQuery(WhereConditionConstants.WHERE, " ".join([property, operator, value_cypher]))
@@ -437,6 +461,7 @@ class DeclarativeBase(ABC):
         return self
 
     def and_where(self, property: str, operator: str, value: Any) -> "DeclarativeBase":
+        """Creates a AND (expression) statement Cypher partial query."""
         value_cypher = to_cypher_value(value)
         self._query.append(
             WhereConditionPartialQuery(WhereConditionConstants.AND, " ".join([property, operator, value_cypher]))
@@ -445,6 +470,7 @@ class DeclarativeBase(ABC):
         return self
 
     def or_where(self, property: str, operator: str, value: Any) -> "DeclarativeBase":
+        """Creates a OR (expression) statement Cypher partial query."""
         value_cypher = to_cypher_value(value)
         self._query.append(
             WhereConditionPartialQuery(WhereConditionConstants.OR, " ".join([property, operator, value_cypher]))
@@ -453,51 +479,61 @@ class DeclarativeBase(ABC):
         return self
 
     def unwind(self, list_expression: str, variable: str) -> "DeclarativeBase":
+        """Creates a UNWIND statement Cypher partial query."""
         self._query.append(UnwindPartialQuery(list_expression, variable))
 
         return self
 
     def with_(self, results: Optional[Dict[str, str]] = {}) -> "DeclarativeBase":
+        """Creates a WITH statement Cypher partial query."""
         self._query.append(WithPartialQuery(results))
 
         return self
 
     def union(self, include_duplicates: Optional[bool] = True) -> "DeclarativeBase":
+        """Creates a UNION statement Cypher partial query."""
         self._query.append(UnionPartialQuery(include_duplicates))
 
         return self
 
     def delete(self, variable_expressions: List[str], detach: Optional[bool] = False) -> "DeclarativeBase":
+        """Creates a DELETE statement Cypher partial query."""
         self._query.append(DeletePartialQuery(variable_expressions, detach))
 
         return self
 
     def remove(self, items: List[str]) -> "DeclarativeBase":
+        """Creates a REMOVE statement Cypher partial query."""
         self._query.append(RemovePartialQuery(items))
 
         return self
 
     def yield_(self, results: Optional[Dict[str, str]] = {}) -> "DeclarativeBase":
+        """Creates a YIELD statement Cypher partial query."""
         self._query.append(YieldPartialQuery(results))
 
         return self
 
     def return_(self, results: Optional[Dict[str, str]] = {}) -> "DeclarativeBase":
+        """Creates a RETURN statement Cypher partial query."""
         self._query.append(ReturnPartialQuery(results))
 
         return self
 
     def order_by(self, properties: str) -> "DeclarativeBase":
+        """Creates a ORDER BY statement Cypher partial query."""
         self._query.append(OrderByPartialQuery(properties))
 
         return self
 
     def limit(self, integer_expression: str) -> "DeclarativeBase":
+        """Creates a LIMIT statement Cypher partial query."""
         self._query.append(LimitPartialQuery(integer_expression))
 
         return self
 
     def skip(self, integer_expression: str) -> "DeclarativeBase":
+        """Creates a SKIP statement Cypher partial query."""
         self._query.append(SkipPartialQuery(integer_expression))
 
         return self
@@ -508,6 +544,7 @@ class DeclarativeBase(ABC):
         return self
 
     def get_single(self, retrieve: str) -> Any:
+        """Returns a single result with a `retrieve` variable name."""
         query = self._construct_query()
 
         result = next(self._connection.execute_and_fetch(query), None)
@@ -517,10 +554,12 @@ class DeclarativeBase(ABC):
         return result
 
     def execute(self) -> Iterator[Dict[str, Any]]:
+        """Executes the Cypher query."""
         query = self._construct_query()
         return self._connection.execute_and_fetch(query)
 
     def _construct_query(self) -> str:
+        """Constructs the (partial) Cypher query so it can be executed."""
         query = [""]
 
         # if not self._any_variables_matched():
@@ -534,12 +573,14 @@ class DeclarativeBase(ABC):
         return joined_query
 
     def _any_variables_matched(self) -> bool:
+        """Checks if any variables are present in the result."""
         return any(
             q.type in [DeclarativeBaseTypes.EDGE, DeclarativeBaseTypes.NODE] and q.variable not in [None, ""]
             for q in self._query
         )
 
     def _is_linking_valid_with_query(self, match_type: str):
+        """Checks if linking functions match the current query."""
         return len(self._query) == 0 or self._query[-1].type != match_type
 
 
